@@ -14,4 +14,4 @@
 # ========================×========================
 
 from .client import *
-from .startup import StartPyrogram
+from .startup import StartPyrogram, clients, client_id
