@@ -19,7 +19,7 @@ try:
     from uvloop import install
 except:
     install = None
-    raise DependencyMissingError("'uvloop' not installed\ninstall 'uvloop' or add 'uvloop' in requirements.txt")
+    logs.info("'uvloop' not installed\ninstall 'uvloop' or add 'uvloop' in requirements.txt")
 
 
 MSG_ON = """
@@ -51,6 +51,5 @@ async def start_main():
     await aiosession.close()
 
 if __name__ == "__main__":
-    print(f"Starting AyiinUbot - {ayiin_ver}")
     install()
     loop.run_until_complete(start_main())
