@@ -6,7 +6,7 @@
 # <https://www.github.com/AyiinXd/pyAyiin/blob/main/LICENSE/>.
 #
 # FROM py-Ayiin <https://github.com/AyiinXd/pyAyiin>
-# t.me/AyiinXdSupport & t.me/AyiinSupport
+# t.me/AyiinChat & t.me/AyiinSupport
 
 
 # ========================×========================
@@ -26,6 +26,10 @@ class PyrogramMissingError(ImportError):
     ...
 
 
+class TelethonMissingError(ImportError):
+    ...
+
+
 class DependencyMissingError(ImportError):
     ...
 
