@@ -14,14 +14,19 @@
 # ========================×========================
 
 from ._database import AyiinDB
+from ._misc import _Misc
 from .converter import Convert
+from .func import update_envs
 from .helpers import Helpers
 from .hosting import where_hosted
+from .Inline import InlineBot
 from .queue import Queue
 
 
 class Methods(
+    _Misc,
     Convert,
+    InlineBot,
     Helpers,
     Queue,
 ):
